==> jc-1.4.0.tar.gz: soot/jimple/toolkits/callgraph/CallGraphBuilder.h <==
// public final class soot.jimple.toolkits.callgraph.CallGraphBuilder

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2fbe5e2642133ee1 soot_jimple_toolkits_callgraph_CallGraphBuilder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_CallGraphBuilder_H_
#define _JC_soot_jimple_toolkits_callgraph_CallGraphBuilder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_PointsToAnalysis$object;
struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object;
struct _jc_soot_jimple_toolkits_callgraph_ContextManager$object;
struct _jc_soot_jimple_toolkits_callgraph_OnFlyCallGraphBuilder$object;
struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object;
struct _jc_soot_options_CGOptions$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$sub_refs	_jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$refs	_jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$nonrefs	_jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$object	_jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$vmethods	_jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$vtable	_jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$vtype	_jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$object *);
extern void _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$method$_init$81b5f411ff09cc2b(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$object *, struct _jc_object *);

// Virtual methods
extern void _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$method$build$8dbf5d5babe4b103(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$object *);
extern struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object *_jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$method$getCallGraph$4562ff27ccec4086(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$object *);
extern struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *_jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$method$reachables$9e04a85c10d1b26e(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$method_info$build$8dbf5d5babe4b103;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$method_info$getCallGraph$4562ff27ccec4086;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$method_info$reachables$9e04a85c10d1b26e;

// Static methods
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$method$makeContextManager$e1ab9a8a13d297a8(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object *);

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$vmethods {
	void	(*build$8dbf5d5babe4b103)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$object *);
	struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object	*(*getCallGraph$4562ff27ccec4086)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$object *);
	struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object	*(*reachables$9e04a85c10d1b26e)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$vmethods	soot_jimple_toolkits_callgraph_CallGraphBuilder;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$sub_refs {
	struct _jc_object	*pa;
	struct _jc_soot_options_CGOptions$object	*options;
	struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object	*reachables;
	struct _jc_soot_jimple_toolkits_callgraph_OnFlyCallGraphBuilder$object	*ofcgb;
	struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object	*cg;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$refs {
    _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$sub_refs	soot_jimple_toolkits_callgraph_CallGraphBuilder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$sub_nonrefs {
	jboolean	appOnly;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$sub_nonrefs	soot_jimple_toolkits_callgraph_CallGraphBuilder;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$object {
	_jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$vtype _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_CallGraphBuilder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_CallGraphBuilder_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/callgraph/CallGraphBuilder.h <==
// public final class soot.jimple.toolkits.callgraph.CallGraphBuilder

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2fbe5e2642133ee1 soot_jimple_toolkits_callgraph_CallGraphBuilder

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_callgraph_CallGraphBuilder_H_
#define _JC_soot_jimple_toolkits_callgraph_CallGraphBuilder_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_PointsToAnalysis$object;
struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object;
struct _jc_soot_jimple_toolkits_callgraph_ContextManager$object;
struct _jc_soot_jimple_toolkits_callgraph_OnFlyCallGraphBuilder$object;
struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object;
struct _jc_soot_options_CGOptions$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$sub_refs	_jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$sub_refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$sub_nonrefs	_jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$refs	_jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$refs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$nonrefs	_jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$nonrefs;
typedef struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$object	_jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$object;

typedef const struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$vmethods	_jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$vmethods;
typedef const struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$vtable	_jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$vtable;
typedef const struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$vtype	_jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$method$_init$81b5f411ff09cc2b(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$method$build$8dbf5d5babe4b103(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object *_jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$method$getCallGraph$4562ff27ccec4086(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object *_jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$method$reachables$9e04a85c10d1b26e(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$method_info$build$8dbf5d5babe4b103;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$method_info$getCallGraph$4562ff27ccec4086;
extern _jc_method _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$method_info$reachables$9e04a85c10d1b26e;

// Static methods
extern struct _jc_object *_jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$method$makeContextManager$e1ab9a8a13d297a8(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$vmethods {
	void	(*build$8dbf5d5babe4b103)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object	*(*getCallGraph$4562ff27ccec4086)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object	*(*reachables$9e04a85c10d1b26e)(_jc_env *, struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$vmethods	soot_jimple_toolkits_callgraph_CallGraphBuilder;
};

// Vtype
struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$sub_refs {
	struct _jc_object	*pa;
	struct _jc_soot_options_CGOptions$object	*options;
	struct _jc_soot_jimple_toolkits_callgraph_ReachableMethods$object	*reachables;
	struct _jc_soot_jimple_toolkits_callgraph_OnFlyCallGraphBuilder$object	*ofcgb;
	struct _jc_soot_jimple_toolkits_callgraph_CallGraph$object	*cg;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$refs {
    _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$sub_refs	soot_jimple_toolkits_callgraph_CallGraphBuilder;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$sub_nonrefs {
	jboolean	appOnly;
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$sub_nonrefs	soot_jimple_toolkits_callgraph_CallGraphBuilder;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$object {
	_jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$vtype	*vtype;
	_jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$vtype _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_callgraph_CallGraphBuilder, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_callgraph_CallGraphBuilder$class_object;

#endif	/* _JC_soot_jimple_toolkits_callgraph_CallGraphBuilder_H_ */
